Function fred::util::static_str
source · pub const fn static_str(s: &'static str) -> StrExpand description
Create a Str from a static str slice without copying.
pub const fn static_str(s: &'static str) -> StrCreate a Str from a static str slice without copying.